==> tutti-ui-swing-2.5.1-sources.jar: fr/ifremer/tutti/ui/swing/content/EditSampleCategoryModelAction.java <==
package fr.ifremer.tutti.ui.swing.content;

/*
 * #%L
 * Tutti :: UI
 * $Id: EditSampleCategoryModelAction.java 1170 2013-09-13 16:21:34Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.5.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/EditSampleCategoryModelAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.TuttiScreen;

import static org.nuiton.i18n.I18n._;

/**
 * To show {@link TuttiScreen#EDIT_SAMPLE_CATEGORY_MODEL} config screen.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.4
 */
public class EditSampleCategoryModelAction extends AbstractChangeScreenAction {

    public EditSampleCategoryModelAction(MainUIHandler handler) {
        super(handler, true, TuttiScreen.EDIT_SAMPLE_CATEGORY_MODEL);
    }

    @Override
    public boolean prepareAction() throws Exception {
        boolean result = super.prepareAction();
        if (result) {
            result = askAdminPassword(
                    _("tutti.editSampleCategoryModel.passwordDialog.message"),
                    _("tutti.editSampleCategoryModel.passwordDialog.title"),
                    _("tutti.editSampleCategoryModel.passwordDialog.error.message"),
                    _("tutti.editSampleCategoryModel.passwordDialog.error.title")
            );
        }
        return result;
    }
}

==> tutti-ui-swing-2.6-sources.jar: fr/ifremer/tutti/ui/swing/content/EditSampleCategoryModelAction.java <==
package fr.ifremer.tutti.ui.swing.content;

/*
 * #%L
 * Tutti :: UI
 * $Id: EditSampleCategoryModelAction.java 1170 2013-09-13 16:21:34Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.6/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/EditSampleCategoryModelAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.TuttiScreen;

import static org.nuiton.i18n.I18n._;

/**
 * To show {@link TuttiScreen#EDIT_SAMPLE_CATEGORY_MODEL} config screen.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.4
 */
public class EditSampleCategoryModelAction extends AbstractChangeScreenAction {

    public EditSampleCategoryModelAction(MainUIHandler handler) {
        super(handler, true, TuttiScreen.EDIT_SAMPLE_CATEGORY_MODEL);
    }

    @Override
    public boolean prepareAction() throws Exception {
        boolean result = super.prepareAction();
        if (result) {
            result = askAdminPassword(
                    _("tutti.editSampleCategoryModel.passwordDialog.message"),
                    _("tutti.editSampleCategoryModel.passwordDialog.title"),
                    _("tutti.editSampleCategoryModel.passwordDialog.error.message"),
                    _("tutti.editSampleCategoryModel.passwordDialog.error.title")
            );
        }
        return result;
    }
}
